@@ -407,6 +407,7 @@ Erase it? Y/N: """) % locals())
         init.write_select_db(tracker_home, backend)
 
         print _("""
+---------------------------------------------------------------------------
  You should now edit the tracker configuration file:
    %(config_file)s""") % {"config_file": config_ini_file}
 
@@ -427,6 +428,10 @@ Erase it? Y/N: """) % locals())
  You may also change the database initialisation file:
    %(database_init_file)s
  ... see the documentation on customizing for more information.
+
+ You MUST run the "roundup-admin initialise" command once you've performed
+ the above steps.
+---------------------------------------------------------------------------
 """) % {
     'database_config_file': os.path.join(tracker_home, 'schema.py'),
     'database_init_file': os.path.join(tracker_home, 'initial_data.py'),
@@ -645,7 +650,12 @@ Erase it? Y/N: """))
                 values = [value]
             d = props[propname] = {}
             for value in values:
-                d[hyperdb.rawToHyperdb(self.db, cl, None, propname, value)] = 1
+                value = hyperdb.rawToHyperdb(self.db, cl, None, propname, value)
+                if isinstance(value, list):
+                    for entry in value:
+                        d[entry] = 1
+                else:
+                    d[value] = 1
 
         # now do the find
         try:
@@ -1050,6 +1060,10 @@ Erase it? Y/N: """))
         class colon_separated(csv.excel):
             delimiter = ':'
 
+        # make sure target dir exists
+        if not os.path.exists(dir):
+            os.makedirs(dir)
+
         # do all the classes specified
         for classname in classes:
             cl = self.get_class(classname)
@@ -1119,7 +1133,7 @@ Erase it? Y/N: """))
             cl = self.get_class(classname)
 
             # ensure that the properties and the CSV file headings match
-            f = open(os.path.join(dir, file), 'rU')
+            f = open(os.path.join(dir, file), 'r')
             reader = csv.reader(f, colon_separated)
             file_props = None
             maxid = 1
